@@ -43,6 +43,7 @@ typedef struct {
 extern ArvDebugCategory arv_debug_category_dom;
 extern ArvDebugCategory arv_debug_category_interface;
 extern ArvDebugCategory arv_debug_category_device;
+extern ArvDebugCategory arv_debug_category_chunk;
 extern ArvDebugCategory arv_debug_category_stream;
 extern ArvDebugCategory arv_debug_category_stream_thread;
 extern ArvDebugCategory arv_debug_category_gvcp;
@@ -63,6 +64,10 @@ extern ArvDebugCategory arv_debug_category_misc;
 #define arv_log_device(...)		arv_log (&arv_debug_category_device, __VA_ARGS__)
 #define arv_warning_device(...)		arv_warning (&arv_debug_category_device, __VA_ARGS__)
 
+#define arv_debug_chunk(...) 		arv_debug (&arv_debug_category_chunk, __VA_ARGS__)
+#define arv_log_chunk(...)		arv_log (&arv_debug_category_chunk, __VA_ARGS__)
+#define arv_warning_chunk(...)		arv_warning (&arv_debug_category_chunk, __VA_ARGS__)
+
 #define arv_debug_stream(...) 		arv_debug (&arv_debug_category_stream, __VA_ARGS__)
 #define arv_log_stream(...)		arv_log (&arv_debug_category_stream, __VA_ARGS__)
 #define arv_warning_stream(...)		arv_warning (&arv_debug_category_stream, __VA_ARGS__)
